#############
API
#############


Here we document the `PSDEstimator`, the main class to be used from this package.


.. autoclass:: sgvb_psd.psd_estimator.PSDEstimator
    :members:
    :private-members: